==> aws-android-sdk-sqs-2.2.0-sources.jar: com/amazonaws/services/sqs/model/transform/TooManyEntriesInBatchRequestExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.sqs.model.transform;

import org.w3c.dom.Node;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.util.XpathUtils;
import com.amazonaws.transform.StandardErrorUnmarshaller;

import com.amazonaws.services.sqs.model.TooManyEntriesInBatchRequestException;

public class TooManyEntriesInBatchRequestExceptionUnmarshaller extends StandardErrorUnmarshaller {

    public TooManyEntriesInBatchRequestExceptionUnmarshaller() {
        super(TooManyEntriesInBatchRequestException.class);
    }

    public AmazonServiceException unmarshall(Node node) throws Exception {
        // Bail out if this isn't the right error code that this
        // marshaller understands.
        String errorCode = parseErrorCode(node);
        if (errorCode == null || !errorCode.equals("AWS.SimpleQueueService.TooManyEntriesInBatchRequest"))
            return null;

        TooManyEntriesInBatchRequestException e = (TooManyEntriesInBatchRequestException)super.unmarshall(node);
        
        return e;
    }
}

==> aws-android-sdk-sqs-2.2.21-sources.jar: com/amazonaws/services/sqs/model/transform/TooManyEntriesInBatchRequestExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sqs.model.transform;

import org.w3c.dom.Node;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.util.XpathUtils;
import com.amazonaws.transform.StandardErrorUnmarshaller;

import com.amazonaws.services.sqs.model.TooManyEntriesInBatchRequestException;

public class TooManyEntriesInBatchRequestExceptionUnmarshaller extends StandardErrorUnmarshaller {

    public TooManyEntriesInBatchRequestExceptionUnmarshaller() {
        super(TooManyEntriesInBatchRequestException.class);
    }

    public AmazonServiceException unmarshall(Node node) throws Exception {
        // Bail out if this isn't the right error code that this
        // marshaller understands.
        String errorCode = parseErrorCode(node);
        if (errorCode == null
                || !errorCode.equals("AWS.SimpleQueueService.TooManyEntriesInBatchRequest"))
            return null;

        TooManyEntriesInBatchRequestException e = (TooManyEntriesInBatchRequestException) super
                .unmarshall(node);

        return e;
    }
}
